@@ -35,9 +35,14 @@ class ForecasterParalleLauncher():
         self.key_args.sort()
         self.counter = 1
         for me_arg in self.key_args:
-            continuous_saving_key, two_states_saving_key, two_states_saving_key_lo, three_states_saving_key, three_states_saving_key_lo, _ = self.create_saving_key(*me_arg)
+            continuous_saving_key, continuous_saving_key_scale_one, continuous_saving_key_scale_two, two_states_saving_key, two_states_saving_key_lo, three_states_saving_key, three_states_saving_key_lo, _ = self.create_saving_key(
+                *me_arg)
             self.mapping_keys[continuous_saving_key] = self.counter
             self.counter = self.counter + 1
+            self.mapping_keys[continuous_saving_key_scale_one] = self.counter
+            self.counter = self.counter + 1
+            self.mapping_keys[continuous_saving_key_scale_two] = self.counter
+            self.counter = self.counter + 1
             self.mapping_keys[two_states_saving_key] = self.counter
             self.counter = self.counter + 1
             self.mapping_keys[two_states_saving_key_lo] = self.counter
@@ -65,16 +70,16 @@ class ForecasterParalleLauncher():
         self.empty_runs_to_investigate = []
         self.dbx = dropbox_file_saver.NaPoleonDropboxConnector(drop_token=drop_token,dropbox_backup=dropbox_backup)
 
-    def create_saving_key(self,seed, n, s, s_eval, calibration_step, signal_type, idios_string):
+    def create_saving_key(self, seed, n, s, s_eval, calibration_step, signal_type, idios_string):
         idios = json.loads(idios_string)
-        common_params ={
-            'seed':seed,
-            'n':n,
-            's':s,
-            's_eval':s_eval,
-            'calibration_step':calibration_step,
-            'signal_type' : signal_type,
-            'discretization':0,
+        common_params = {
+            'seed': seed,
+            'n': n,
+            's': s,
+            's_eval': s_eval,
+            'calibration_step': calibration_step,
+            'signal_type': signal_type,
+            'discretization': 0,
             'type': 'continuous'
         }
         common_params.update(idios)
@@ -82,7 +87,7 @@ class ForecasterParalleLauncher():
         continuous_saving_key = signal_utility.convert_to_sql_column_format(continuous_saving_key)
 
         common_params.update({
-            'discretization':2,
+            'discretization': 1,
             'type': 'long short'
         })
         two_states_saving_key = json.dumps(common_params, sort_keys=True)
@@ -96,20 +101,35 @@ class ForecasterParalleLauncher():
         two_states_saving_key_lo = signal_utility.convert_to_sql_column_format(two_states_saving_key_lo)
 
         common_params.update({
-            'discretization':3,
+            'discretization': 3,
             'type': 'long short'
         })
         three_states_saving_key = json.dumps(common_params, sort_keys=True)
         three_states_saving_key = signal_utility.convert_to_sql_column_format(three_states_saving_key)
 
         common_params.update({
-            'discretization': 3,
+            'discretization': 4,
             'type': 'long only'
         })
         three_states_saving_key_lo = json.dumps(common_params, sort_keys=True)
         three_states_saving_key_lo = signal_utility.convert_to_sql_column_format(three_states_saving_key_lo)
 
-        return continuous_saving_key, two_states_saving_key, three_states_saving_key_lo, three_states_saving_key, three_states_saving_key_lo, idios
+        common_params.update({
+            'discretization': -1,
+            'type': 'long short'
+        })
+        continuous_saving_key_scale_one = json.dumps(common_params, sort_keys=True)
+        continuous_saving_key_scale_one = signal_utility.convert_to_sql_column_format(continuous_saving_key_scale_one)
+
+        common_params.update({
+            'discretization': -2,
+            'type': 'long short'
+        })
+
+        continuous_saving_key_scale_two = json.dumps(common_params, sort_keys=True)
+        continuous_saving_key_scale_two = signal_utility.convert_to_sql_column_format(continuous_saving_key_scale_two)
+
+        return continuous_saving_key, continuous_saving_key_scale_one, continuous_saving_key_scale_two, two_states_saving_key, three_states_saving_key_lo, three_states_saving_key, three_states_saving_key_lo, idios
 
     def launchParallelPool(self, toRun, use_num_cpu):
         with Pool(processes=use_num_cpu) as pool:
