@@ -85,6 +85,23 @@ def roll_wrapper(rolled_df, lookback_window, skipping_size, function_to_apply, t
     rolled_df = rolled_df.iloc[skipping_size:]
     return rolled_df
 
+def roll_cointegration_wrapper(rolled_df, lookback_window, skipping_size, function_to_apply, trigger, suffixes):
+    x_suffixe,y_suffixe = suffixes
+    signal_gen_x, signal_gen_y = 'signal_gen' + x_suffixe, 'signal_gen' + y_suffixe
+    signal_x, signal_y = 'signal' + x_suffixe, 'signal' + y_suffixe
+    signal_df = roll(rolled_df, lookback_window).apply(function_to_apply)
+    signal_df = signal_df.to_frame()
+    signal_df.columns = ['signal']
+    signal_df[[signal_gen_x, signal_gen_y]] = pd.DataFrame(signal_df['signal'].tolist(), index=signal_df.index)
+    signal_df[[signal_x, signal_y]] = signal_df[[signal_gen_x, signal_gen_y]].shift()
+    if trigger:
+        signal_df[signal_x] = signal_df[signal_x].fillna(method='ffill')
+        signal_df[signal_y] = signal_df[signal_y].fillna(method='ffill')
+    signal_df = signal_df.fillna(0.)
+    rolled_df = pd.merge(rolled_df, signal_df, how='left', left_index=True, right_index=True)
+    rolled_df = rolled_df.iloc[skipping_size:]
+    return rolled_df
+
 def roll(df, w):
     v = df.values
     d0, d1 = v.shape
@@ -824,3 +841,43 @@ def transform_daily_shifted_to_hourly(drop_token=None,local_root_directory=None,
     all__parallel_results_df.to_pickle(local_root_directory + ssj+'_shifted_parallel_results_df.pickle')
     return all_signals_df, all__parallel_results_df
 
+def get_weekly_data_from_daily_data(data=None):
+    weekly_df = pd.DataFrame()
+    all_columns = data.columns
+    for col in all_columns:
+        if 'close' in col:
+            current_weekly_col = data[col].resample('W').last()
+        if 'open' in col:
+            current_weekly_col = data[col].resample('W').first()
+        if 'high' in col:
+            current_weekly_col = data[col].resample('W').max()
+        if 'low' in col:
+            current_weekly_col = data[col].resample('W').min()
+        if 'volume' in col:
+            current_weekly_col = data[col].resample('W').sum()
+        if weekly_df.empty:
+            weekly_df = pd.DataFrame(current_weekly_col, columns=[col])
+        else:
+            weekly_df[col] = pd.DataFrame(current_weekly_col)
+    return weekly_df
+
+def get_freq_daily_data_from_daily_data(data=None, freq='3D'):
+    freq_daily_df = pd.DataFrame()
+    all_columns = data.columns
+    for col in all_columns:
+        if 'close' in col:
+            current_freq_daily_col = data[col].resample(freq).last()
+        if 'open' in col:
+            current_freq_daily_col = data[col].resample(freq).first()
+        if 'high' in col:
+            current_freq_daily_col = data[col].resample(freq).max()
+        if 'low' in col:
+            current_freq_daily_col = data[col].resample(freq).min()
+        if 'volume' in col:
+            current_freq_daily_col = data[col].resample(freq).sum()
+        if freq_daily_df.empty:
+            freq_daily_df = pd.DataFrame(current_freq_daily_col, columns=[col])
+        else:
+            freq_daily_df[col] = pd.DataFrame(current_freq_daily_col)
+    return freq_daily_df
+
